@@ -308,11 +308,11 @@ class Store(Generic[State, Action, Event]):
         if isinstance(obj, (int, float, str, bool, NoneType)):
             return obj
         if callable(obj):
-            return Store.serialize_value(obj())
+            return cls.serialize_value(obj())
         if isinstance(obj, (list, tuple)):
-            return [Store.serialize_value(i) for i in obj]
+            return [cls.serialize_value(i) for i in obj]
         if is_immutable(obj):
-            return Store._serialize_dataclass_to_dict(obj)
+            return cls._serialize_dataclass_to_dict(obj)
         msg = f'Unable to serialize object with type `{type(obj)}`.'
         raise TypeError(msg)
 
@@ -323,6 +323,6 @@ class Store(Generic[State, Action, Event]):
     ) -> dict[str, Any]:
         result = {}
         for field in dataclasses.fields(obj):
-            value = Store.serialize_value(getattr(obj, field.name))
+            value = cls.serialize_value(getattr(obj, field.name))
             result[field.name] = value
         return result
